import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getPermissions } from '@/api/base'
import appConfigList from '@/app.config.js'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    permissions: [],
    appConfig: {},
    appConfigList
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setPermissions(state, permissions) {
      state.permissions = permissions
    },
    setAppConfig(state, appConfig) {
      state.appConfig = appConfig
      localStorage.setItem('app_config', JSON.stringify(appConfig))
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit, dispatch }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      await dispatch('getPermissions')
      return isLogin
    },
    // 获取所有权限列表
    async getPermissions({ commit }) {
      await getPermissions().then(res => {
        if (res.data && res.data.items) {
          commit('setPermissions', res.data.items)
        }
      })
    },
    // 设置App配置
    setAppConfig({ commit }) {
      const found = appConfigList.find(item => {
        return item.hosts.find(host => location.host.includes(host))
      })
      // 获取本地App配置
      let localAppConfig = localStorage.getItem('app_config')
      if (localAppConfig) {
        try {
          localAppConfig = JSON.parse(localAppConfig)
        } catch (error) {
          localAppConfig = null
        }
      }
      const appConfig = found || localAppConfig || appConfigList[0]
      commit('setAppConfig', appConfig)
    }
  }
})
// 设置项目配置
store.dispatch('setAppConfig')

export default store
